@@ -2,8 +2,6 @@
 #
 # autogen.sh - Generates initial makefiles from a pristine CVS tree
 #
-# $Id: autogen.sh 10552 2005-08-11 16:02:48Z cmdjb $
-#
 # USAGE:
 #   autogen.sh [configure options]
 #
@@ -47,29 +45,34 @@ CONFIG_DIR=${CONFIG_DIR-../config}
 # Set an envariable of the same name in uppercase, to override scan
 #
 programs="automake aclocal autoconf autoheader libtoolize"
-if grep "^GTK_DOC_CHECK" configure.ac >/dev/null; then
+confs=`find . -name configure.ac -print`
+if grep "^GTK_DOC_CHECK" $confs >/dev/null; then
   programs="$programs gtkdocize"
 fi
-if grep "^AC_CHECK_PROGS.SWIG" configure.ac >/dev/null; then
+if grep "^AC_CHECK_PROGS.SWIG" $confs >/dev/null; then
   programs="$programs swig"
 fi
+ltdl=
+if grep "^AC_LIBLTDL_" $confs >/dev/null; then
+  ltdl="--ltdl"
+fi
 
 # Some dependencies for autotools:
 # automake 1.9 requires autoconf 2.58
 # automake 1.8 requires autoconf 2.58
 # automake 1.7 requires autoconf 2.54
-automake_min_vers=1.7
+automake_min_vers=010700
 aclocal_min_vers=$automake_min_vers
-autoconf_min_vers=2.54
+autoconf_min_vers=025400
 autoheader_min_vers=$autoconf_min_vers
-libtoolize_min_vers=1.4
-gtkdocize_min_vers=1.3
-swig_min_vers=1.3.24
+libtoolize_min_vers=010400
+gtkdocize_min_vers=010300
+swig_min_vers=010324
 
 # Default program arguments
 automake_args="--add-missing"
 autoconf_args=
-libtoolize_args="--force --copy --automake"
+libtoolize_args="$ltdl --force --copy --automake"
 gtkdocize_args="--copy"
 aclocal_args=
 automake_args="--gnu --add-missing --force --copy"
@@ -92,46 +95,93 @@ if test "X$DRYRUN" != X; then
   DRYRUN=echo
 fi
 
+cat > autogen-get-version.pl <<EOF
+use File::Basename;
+my \$prog=basename \$0;
+die "\$prog: USAGE PATH PROGRAM-NAME\n  e.g. \$prog /usr/bin/foo-123 foo\n"
+  unless @ARGV==2;
+
+my(\$path,\$name)=@ARGV;
+exit 0 if !-f \$path;
+die "\$prog: \$path not found\n" if !-r \$path;
+
+my \$mname=\$name; \$mname =~ s/^g(libtoolize)\$/\$1/;
+
+my(@vnums);
+for my \$varg (qw(--version -version)) {
+  my \$cmd="\$path \$varg";
+  open(PIPE, "\$cmd 2>&1 |") || next;
+  while(<PIPE>) {
+    chomp;
+    next if @vnums; # drain pipe if we got a vnums
+    next unless /^\$mname/i;
+    my(\$v)=/(\S+)\$/i; \$v =~ s/-.*\$//;
+    @vnums=grep { defined \$_ && !/^\s*\$/} map { s/\D//g; \$_; } split(/\./, \$v);
+  }
+  close(PIPE);
+  last if @vnums;
+}
+
+@vnums=(@vnums, 0, 0, 0)[0..2];
+print join('', map { sprintf('%02d', \$_) } @vnums)."\n";
+exit 0;
+EOF
+
+autogen_get_version="`pwd`/autogen-get-version.pl"
+
+trap "rm -f $autogen_get_version" 0 1 9 15
+
+
 update_prog_version() {
-  prog=$1
+  dir=$1
+  prog=$2
 
   # If there exists an envariable PROG in uppercase, use that and do not scan
   ucprog=`echo $prog | tr 'a-z' 'A-Z' `
   eval env=\$${ucprog}
   if test X$env != X; then
     prog_name=$env
-    prog_vers=`$prog_name --version 2>&1 | head -n 1 | awk '{print $NF}'`
+    prog_vers=`perl $autogen_get_version $prog_name $prog`
+
     eval ${prog}_name=${prog_name}
     eval ${prog}_vers=${prog_vers}
+    eval ${prog}_dir=environment
     return
   fi
 
   eval prog_name=\$${prog}_name
   eval prog_vers=\$${prog}_vers
+  eval prog_dir=\$${prog}_dir
   if test X$prog_vers = X; then
     prog_vers=0
   fi
 
+  save_PATH="$PATH"
+
+  cd "$dir"
+  PATH=".:$PATH"
+
   names=`ls $prog* 2>/dev/null`
   if [ "X$names" != "X" ]; then
     for name in $names; do
-      vers=`$name --version 2>&1 | grep -v Unable | head -n 1 | awk '{print $NF}'`
+      vers=`perl $autogen_get_version $dir/$name $prog`
       if [ "X$vers" = "X" ]; then
-        vers=`$name -version 2>&1 | grep Version | awk '{print $NF}'`
-        if [ "X$vers" = "X" ]; then
-          continue
-        fi
+        continue
       fi
+
       if expr $vers '>' $prog_vers >/dev/null; then
         prog_name=$name
         prog_vers=$vers
+        prog_dir="$dir"
       fi
     done
   fi
 
   eval ${prog}_name=${prog_name}
   eval ${prog}_vers=${prog_vers}
+  eval ${prog}_dir=${prog_dir}
 
+  PATH="$save_PATH"
 }
 
 
@@ -142,13 +192,14 @@ check_prog_version() {
 
   eval prog_name=\$${prog}_name
   eval prog_vers=\$${prog}_vers
+  eval prog_dir=\$${prog}_dir
 
-  echo "$program: Found $prog program '$prog_name' version $prog_vers (min $min)" 1>&2
+  echo "$program: $prog program '$prog_name' V $prog_vers (min $min) in $prog_dir" 1>&2
 
   rc=1
   if test $prog_vers != 0; then
     if expr $prog_vers '<' $min >/dev/null; then
-       echo "$program: ERROR: \`$prog' version $prog_vers is too old."
+       echo "$program: ERROR: \`$prog' version $prog_vers in $prog_dir is too old."
        echo "    (version $min or newer is required)"
        rc=0
     else
@@ -178,13 +229,12 @@ here=`pwd`
 while [ $# -ne 0 ] ; do
   dir=$1
   shift
-  if [ ! -d $dir ]; then
+  if [ ! -d "$dir" ]; then
     continue
   fi
-  cd $dir
 
   for prog in $programs; do
-    update_prog_version $prog
+    update_prog_version "$dir" $prog
   done
 done
 cd $here
@@ -202,6 +252,9 @@ done
 
 echo "$program: Dependencies satisfied"
 
+if test -d $SRCDIR/libltdl; then
+  touch $SRCDIR/libltdl/NO-AUTO-GEN
+fi
 
 config_dir=
 if test -d $CONFIG_DIR; then
@@ -212,12 +265,12 @@ fi
 for coin in `find $SRCDIR -name configure.ac -print`
 do 
   dir=`dirname $coin`
-  if test -f $dir/NO-AUTO-GEN; then
+  if test -f "$dir/NO-AUTO-GEN"; then
     echo $program: Skipping $dir -- flagged as no auto-gen
   else
     echo " "
     echo $program: Processing directory $dir
-    ( cd $dir
+    ( cd "$dir"
 
       # Ensure that these are created by the versions on this system
       # (indirectly via automake)
