@@ -2,7 +2,7 @@
 #
 # example.pl - Redland eaxmple Perl program
 #
-# $Id: example.pl 12211 2007-05-06 01:43:25Z dajobe $
+# $Id: example.pl 13257 2007-12-07 22:56:10Z laalto $
 #
 # Copyright (C) 2000-2005 David Beckett - http://purl.org/net/dajobe/
 # Copyright (C) 2000-2005 University of Bristol - http://www.bristol.ac.uk/
@@ -144,7 +144,7 @@ my $str=$results->to_string;
 print "Query results serialized to an XML string size ".length($str)." bytes\n";
 
 print "\nExecuting SPARQL construct query\n";
-my $q2 = new RDF::Redland::Query("CONSTRUCT * WHERE { ?a ?b ?c }", undef, undef, "sparql");
+my $q2 = new RDF::Redland::Query("CONSTRUCT { ?a ?b ?c } WHERE { ?a ?b ?c }", undef, undef, "sparql");
 my $results=$model->query_execute($q2);
 $stream=$results->as_stream;
 $count=0;
