@@ -1,7 +1,7 @@
 # 
 # RDF.py - Redland Python RDF module
 #
-# $Id: RDF.py 12132 2007-04-23 02:01:34Z dajobe $
+# $Id: RDF.py 12479 2007-08-25 04:27:59Z dajobe $
 #
 # Copyright (C) 2000-2006 David Beckett - http://purl.org/net/dajobe/
 # Copyright (C) 2000-2005 University of Bristol - http://www.bristol.ac.uk/
@@ -109,7 +109,7 @@ __all__ = [ "Node",
 __version__ = "1.1"
 
 # For pydoc
-__date__ = '$Date: 2007-04-22 19:01:34 -0700 (Sun, 22 Apr 2007) $'
+__date__ = '$Date: 2007-08-24 21:27:59 -0700 (Fri, 24 Aug 2007) $'
 __author__ = 'Dave Beckett - http://purl.org/net/dajobe, Edd Dumbill <edd@usefulinc.com> and Matt Biddulph <mb@picdiary.com>'
 
 # Package variables [globals]
@@ -1656,18 +1656,18 @@ class Parser(object):
   for the RDF/XML syntax.
   """
   
-  def __init__(self, name="rdfxml", mime_type="", uri=None):
+  def __init__(self, name=None, mime_type=None, uri=None):
     """Create an RDF Parser (constructor).
 
 Create a new RDF Parser for a particular syntax.  The parser is
 chosen by the fields given to the constructor, all of which are
-optional.  When any are given, they must all match.
+optional.  When any are given, they must all match.  The default
+parser is chosen if none are given, which is RDF/XML in the
+standard configuration of Raptor.
 
-  name      - parser name (currently "rdfxml", "ntriples", "turtle" and "rss-tag-soup")
-  mime_type - currently "application/rdf+xml" (default) or "text/plain" (ntriples)
+  name      - parser syntax name
+  mime_type - syntax mime type
   uri       - URI identifying the syntax
-              currently only "http://www.w3.org/TR/rdf-testcases/#ntriples"
-
     """
     #"
     global _world
@@ -1832,24 +1832,68 @@ optional.  When any are given, they must all match.
       value=Node(literal=value)
     Redland.librdf_parser_set_feature(self._parser,uri._reduri,value._node)
 
+  def set_uri_filter(self, filter):
+    """Set a function for rejecting retrieval of URIs seen during parsing.
+
+   Return False or 0 to not reject the URI
+
+   def reject(uri):
+     if "bad" == uri:
+       return True
+     return False
+
+   parser.set_uri_filter(reject)
+"""
+    import Redland_python
+    Redland_python.set_parser_uri_filter(self._parser, filter)
+
 # end class Parser
 
 class RDFXMLParser(Parser):
+  """Redland RDF/XML Parser class
+
+     import RDF
+     parser=RDF.RDFXMLParser()
+  """
   def __init__(self):
     Parser.__init__(self, name = "rdfxml")
 
 class NTriplesParser(Parser):
+  """Redland N-Triples Parser class
+
+     import RDF
+     parser=RDF.NTriplesParser()
+  """
   def __init__(self):
     Parser.__init__(self, name = "ntriples")
 
 class TurtleParser(Parser):
+  """Redland Turtle Parser class
+
+     import RDF
+     parser=RDF.TurtleParser()
+  """
   def __init__(self):
     Parser.__init__(self, name = "turtle")
 
 class RSSTagSoupParser(Parser):
+  """Redland RSS Tag Soup Parser class
+
+     import RDF
+     parser=RDF.RSSTagSoupParser()
+  """
   def __init__(self):
     Parser.__init__(self, name = "rss-tag-soup")
 
+class GRDDLParser(Parser):
+  """Redland GRDDL Parser class
+
+     import RDF
+     parser=RDF.GRDDLParser()
+  """
+  def __init__(self):
+    Parser.__init__(self, name = "grddl")
+
 
 class Query(object):
   """Redland Query interface class
@@ -2070,7 +2114,7 @@ class QueryResults(object):
     if self.is_graph():
       tmpmodel = Model(MemoryStorage())
       tmpmodel.add_statements(self.as_stream())
-      serializer = RDF.Serializer()
+      serializer = Serializer()
       return serializer.serialize_model_to_string(tmpmodel, base_uri)
 
     if self.is_boolean():
@@ -2267,6 +2311,15 @@ class RSS10Serializer(Serializer):
   def __init__(self):
     Serializer.__init__(self, name = "rss-1.0")
 
+class TurtleSerializer(Serializer):
+  """Redland Turtle Serializer class
+
+     import RDF
+     ser=RDF.TurtleSerializer()
+  """
+  def __init__(self):
+    Serializer.__init__(self, name = "turtle")
+
 
 class NS(object):
   """ Redland Namespace Utility Class
