@@ -2,7 +2,7 @@
 # 
 # redlandtest.py - Redland Python RDF model unit tests
 #
-# $Id: redlandtest.py 10609 2006-03-10 05:29:18Z cmdjb $
+# $Id: redlandtest.py 13266 2007-12-12 21:32:58Z laalto $
 #
 # Authors:
 #   Matt Biddulph <mb@picdiary.com>
@@ -350,7 +350,7 @@ class RasqalQueryTestCase (unittest.TestCase):
         self.assert_(count == 3, "Should have found three results in query")
 
     def testSPARQLQueryAsStream(self):
-        q = SPARQLQuery("PREFIX dc: <http://purl.org/dc/elements/1.1/> CONSTRUCT * WHERE {?a dc:title ?c}")
+        q = SPARQLQuery("PREFIX dc: <http://purl.org/dc/elements/1.1/> CONSTRUCT {?a dc:title ?c} WHERE {?a dc:title ?c}")
         s = q.execute(self.model).as_stream()
         self.assert_(s is not None, "execute as_stream should have succeeded")
         rc=self.model.add_statements(s)
@@ -365,7 +365,7 @@ class RasqalQueryTestCase (unittest.TestCase):
         q = SPARQLQuery("PREFIX dc: <http://purl.org/dc/elements/1.1/> SELECT * WHERE {?a dc:title ?c}")
 
         r = q.execute(self.model)
-        expect = 410
+        expect = 377
         self.assert_(r is not None, "execute to_string should have succeeded")
         s = r.to_string()
         self.assert_(len(s) == expect, "to_string should have returned "+str(expect)+" not " + str(len(s)))
@@ -402,6 +402,16 @@ class RasqalQueryTestCase (unittest.TestCase):
 #            count += 1
 #        self.assert_(count == 3, "Should have found three results in execution 2 not "+str(count))
 
+    def testSPARQLQueryTriplesToString(self):
+        q = SPARQLQuery("PREFIX dc: <http://purl.org/dc/elements/1.1/> CONSTRUCT {?a dc:title ?c} WHERE {?a dc:title ?c}")
+
+        r = q.execute(self.model)
+        expect = 294
+        self.assert_(r is not None, "execute to_string should have succeeded")
+        s = r.to_string()
+        self.assert_(len(s) == expect, "to_string should have returned "+str(expect)+" not " + str(len(s)))
+
+
 
 if __name__ == '__main__':
     unittest.main()
