@@ -72,7 +72,7 @@ module Redland
     end
 
     # Sets this node's value to a blank node with the specified ID (?? confirm)
-    def Node.bnode(id=nil)
+    def bnode(id=nil)
       @node = Redland.librdf_new_node_from_blank_identifier($world.world,id)
     end
 
@@ -83,9 +83,9 @@ module Redland
 
     # Creates a new blank node with the specified ID (?? confirm)
     def Node.anon(id)
-      self.initialize()
-      super(id)
-      @node = Redland.librdf_new_node_from_blank_identifier($world.world,id)
+      n = Node.new('')
+      n.bnode(id)
+      n
     end
 
     # Return true if node is a literal
@@ -239,7 +239,7 @@ module Redland
       lang = Redland.librdf_node_get_literal_value_language(node) if Redland.librdf_node_get_literal_value_language(node)
       str = Redland.librdf_node_get_literal_value(node)
       hash_uri = Redland.librdf_node_get_literal_value_datatype_uri(node)
-      hash_uri = Uri(Redland.librdf_uri_to_string(hash_uri)) if hash_uri
+      hash_uri = Uri.new(Redland.librdf_uri_to_string(hash_uri)) if hash_uri
       return Literal.new(str,lang,hash_uri)
     end
 
